@@ -18,6 +18,7 @@ package org.drools.workbench.screens.scenariosimulation.businesscentral.client.e
 
 import java.util.ArrayList;
 import java.util.List;
+import java.util.Optional;
 import java.util.function.Supplier;
 
 import com.google.gwtmockito.GwtMockitoTestRunner;
@@ -27,16 +28,20 @@ import org.drools.scenariosimulation.api.model.ScenarioSimulationModel;
 import org.drools.scenariosimulation.api.model.ScenarioWithIndex;
 import org.drools.scenariosimulation.api.model.Simulation;
 import org.drools.workbench.screens.scenariosimulation.client.TestProperties;
+import org.drools.workbench.screens.scenariosimulation.client.commands.ScenarioSimulationContext;
 import org.drools.workbench.screens.scenariosimulation.client.editor.AbstractScenarioSimulationEditorTest;
 import org.drools.workbench.screens.scenariosimulation.client.editor.strategies.DataManagementStrategy;
 import org.drools.workbench.screens.scenariosimulation.client.handlers.ScenarioSimulationHasBusyIndicatorDefaultErrorCallback;
 import org.drools.workbench.screens.scenariosimulation.client.rightpanel.TestToolsPresenter;
 import org.drools.workbench.screens.scenariosimulation.client.type.ScenarioSimulationResourceType;
+import org.drools.workbench.screens.scenariosimulation.client.widgets.ScenarioGridWidget;
 import org.drools.workbench.screens.scenariosimulation.model.SimulationRunResult;
 import org.drools.workbench.screens.scenariosimulation.service.ImportExportService;
 import org.drools.workbench.screens.scenariosimulation.service.ImportExportType;
 import org.drools.workbench.screens.scenariosimulation.service.RunnerReportService;
 import org.drools.workbench.screens.scenariosimulation.service.ScenarioSimulationService;
+import org.guvnor.common.services.project.client.security.ProjectController;
+import org.guvnor.common.services.project.model.WorkspaceProject;
 import org.guvnor.common.services.shared.metadata.model.Metadata;
 import org.guvnor.messageconsole.client.console.widget.button.AlertsButtonMenuItemBuilder;
 import org.jboss.errai.common.client.api.ErrorCallback;
@@ -74,6 +79,7 @@ import static org.mockito.Matchers.anyBoolean;
 import static org.mockito.Matchers.eq;
 import static org.mockito.Matchers.isA;
 import static org.mockito.Matchers.same;
+import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.spy;
@@ -120,6 +126,12 @@ public class ScenarioSimulationEditorBusinessCentralWrapperTest extends Abstract
     private AssetUpdateValidator assetUpdateValidatorMock;
     @Mock
     private Supplier<ScenarioSimulationModel> contentSupplierMock;
+    @Mock
+    private ProjectController projectControllerMock;
+    @Mock
+    private ScenarioGridWidget backgroundGridWidgetMock;
+    @Mock
+    private ScenarioSimulationContext backgroundContextMock;
 
     private CallerMock<ScenarioSimulationService> scenarioSimulationCaller;
     private CallerMock<ImportExportService> importExportCaller;
@@ -160,6 +172,7 @@ public class ScenarioSimulationEditorBusinessCentralWrapperTest extends Abstract
                 this.metadata = metaDataMock;
                 this.saveAndRenameCommandBuilder = saveAndRenameCommandBuilderMock;
                 this.assetUpdateValidator = assetUpdateValidatorMock;
+                this.projectController = projectControllerMock;
             }
         });
         when(placeRequestMock.getPath()).thenReturn(observablePathMock);
@@ -169,9 +182,12 @@ public class ScenarioSimulationEditorBusinessCentralWrapperTest extends Abstract
         when(scenarioSimulationEditorPresenterMock.getView()).thenReturn(scenarioSimulationViewMock);
         when(scenarioSimulationEditorPresenterMock.getModel()).thenReturn(scenarioSimulationModelMock);
         when(scenarioSimulationEditorPresenterMock.getContentSupplier()).thenReturn(contentSupplierMock);
-        when(scenarioSimulationViewMock.getScenarioGridLayer()).thenReturn(scenarioGridLayerMock);
+        when(scenarioSimulationEditorPresenterMock.getFocusedContext()).thenReturn(scenarioSimulationContextLocal);
+        when(scenarioSimulationEditorPresenterMock.getBackgroundGridWidget()).thenReturn(backgroundGridWidgetMock);
+        when(backgroundGridWidgetMock.getScenarioSimulationContext()).thenReturn(backgroundContextMock);
         when(alertsButtonMenuItemBuilderMock.build()).thenReturn(alertsButtonMenuItemMock);
         when(versionRecordManagerMock.buildMenu()).thenReturn(versionRecordMenuItemMock);
+        when(scenarioGridWidgetMock.getScenarioSimulationContext()).thenReturn(scenarioSimulationContextLocal);
     }
 
     @Test
@@ -275,9 +291,34 @@ public class ScenarioSimulationEditorBusinessCentralWrapperTest extends Abstract
     }
 
     @Test
-    public void makeMenuBar() {
+    public void setSaveEnabledTrue() {
+        scenarioSimulationEditorBusinessClientWrapper.setSaveEnabled(true);
+        verify(scenarioSimulationEditorPresenterMock, times(1)).setSaveEnabled(eq(true));
+    }
+
+    @Test
+    public void setSaveEnabledFalse() {
+        scenarioSimulationEditorBusinessClientWrapper.setSaveEnabled(false);
+        verify(scenarioSimulationEditorPresenterMock, times(1)).setSaveEnabled(eq(false));
+    }
+
+
+    @Test
+    public void makeMenuBarCanUpdateProjectTrue() {
+        doReturn(Optional.of(mock(WorkspaceProject.class))).when(workbenchContextMock).getActiveWorkspaceProject();
+        doReturn(promises.resolve(true)).when(projectControllerMock).canUpdateProject(any());
         scenarioSimulationEditorBusinessClientWrapper.makeMenuBar();
         verify(scenarioSimulationEditorPresenterMock, times(1)).makeMenuBar(same(fileMenuBuilderMock));
+        verify(scenarioSimulationEditorBusinessClientWrapper, times(1)).setSaveEnabled(eq(true));
+    }
+
+    @Test
+    public void makeMenuBarCanUpdateProjectFalse() {
+        doReturn(Optional.of(mock(WorkspaceProject.class))).when(workbenchContextMock).getActiveWorkspaceProject();
+        doReturn(promises.resolve(false)).when(projectControllerMock).canUpdateProject(any());
+        scenarioSimulationEditorBusinessClientWrapper.makeMenuBar();
+        verify(scenarioSimulationEditorPresenterMock, times(1)).makeMenuBar(same(fileMenuBuilderMock));
+        verify(scenarioSimulationEditorBusinessClientWrapper, times(1)).setSaveEnabled(eq(false));
     }
 
     @Test
@@ -299,7 +340,7 @@ public class ScenarioSimulationEditorBusinessCentralWrapperTest extends Abstract
     @Test
     public void synchronizeColumnsDimension() {
         scenarioSimulationEditorBusinessClientWrapper.synchronizeColumnsDimension();
-        verify(scenarioGridModelMock, times(1)).synchronizeFactMappingsWidths();
+        verify(scenarioGridPanelMock, times(1)).synchronizeFactMappingsWidths();
     }
 
     @Test
@@ -315,6 +356,33 @@ public class ScenarioSimulationEditorBusinessCentralWrapperTest extends Abstract
         verify(scenarioSimulationServiceMock, times(1)).loadContent(eq(observablePathMock));
     }
 
+    @Test
+    public void onEditTabSelected() {
+        scenarioSimulationEditorBusinessClientWrapper.onEditTabSelected();
+        verify(scenarioSimulationEditorPresenterMock, times(1)).setFocusedContext(eq(scenarioSimulationContextLocal));
+        verify(scenarioSimulationEditorPresenterMock, times(1)).setItemMenuForMainGridEnabled(eq(true));
+        verify(scenarioGridWidgetMock, times(1)).clearSelections();
+        verify(scenarioGridWidgetMock, times(1)).select();
+        verify(backgroundGridWidgetMock, times(1)).deselect();
+    }
+
+    @Test
+    public void onOverviewSelected() {
+        scenarioSimulationEditorBusinessClientWrapper.onOverviewSelected();
+        verify(scenarioSimulationEditorPresenterMock, times(1)).setFocusedContext(eq(scenarioSimulationContextLocal));
+        verify(scenarioSimulationEditorPresenterMock, times(1)).setItemMenuForMainGridEnabled(eq(true));
+    }
+
+    @Test
+    public void onBackGroundTabSelected() {
+        scenarioSimulationEditorBusinessClientWrapper.enableBackgroundTab();
+        verify(scenarioSimulationEditorPresenterMock, times(1)).setFocusedContext(eq(backgroundContextMock));
+        verify(scenarioSimulationEditorPresenterMock, times(1)).setItemMenuForMainGridEnabled(eq(false));
+        verify(backgroundGridWidgetMock, times(1)).clearSelections();
+        verify(backgroundGridWidgetMock, times(1)).select();
+        verify(scenarioGridWidgetMock, times(1)).deselect();
+    }
+
     @Test
     public void getModelSuccessCallBackMethod_Rule() {
         modelLocal.setSimulation(getSimulation(ScenarioSimulationModel.Type.RULE, null));
