@@ -16,6 +16,7 @@
 package org.drools.workbench.screens.scenariosimulation.client.commands;
 
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.Date;
 import java.util.List;
 import java.util.Objects;
@@ -33,32 +34,37 @@ import org.drools.workbench.screens.scenariosimulation.client.commands.actualcom
 import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.AppendRowCommand;
 import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.DeleteColumnCommand;
 import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.DeleteRowCommand;
-import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.DisableRightPanelCommand;
+import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.DisableTestToolsCommand;
+import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.DuplicateInstanceCommand;
 import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.DuplicateRowCommand;
-import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.EnableRightPanelCommand;
+import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.EnableTestToolsCommand;
+import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.ImportCommand;
 import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.InsertColumnCommand;
 import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.InsertRowCommand;
 import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.PrependColumnCommand;
 import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.PrependRowCommand;
-import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.ReloadRightPanelCommand;
+import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.ReloadTestToolsCommand;
 import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.RunSingleScenarioCommand;
 import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.SetGridCellValueCommand;
 import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.SetHeaderCellValueCommand;
 import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.SetInstanceHeaderCommand;
 import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.SetPropertyHeaderCommand;
+import org.drools.workbench.screens.scenariosimulation.client.editor.ScenarioSimulationEditorPresenter;
 import org.drools.workbench.screens.scenariosimulation.client.events.AppendColumnEvent;
 import org.drools.workbench.screens.scenariosimulation.client.events.AppendRowEvent;
 import org.drools.workbench.screens.scenariosimulation.client.events.DeleteColumnEvent;
 import org.drools.workbench.screens.scenariosimulation.client.events.DeleteRowEvent;
-import org.drools.workbench.screens.scenariosimulation.client.events.DisableRightPanelEvent;
+import org.drools.workbench.screens.scenariosimulation.client.events.DisableTestToolsEvent;
+import org.drools.workbench.screens.scenariosimulation.client.events.DuplicateInstanceEvent;
 import org.drools.workbench.screens.scenariosimulation.client.events.DuplicateRowEvent;
-import org.drools.workbench.screens.scenariosimulation.client.events.EnableRightPanelEvent;
+import org.drools.workbench.screens.scenariosimulation.client.events.EnableTestToolsEvent;
+import org.drools.workbench.screens.scenariosimulation.client.events.ImportEvent;
 import org.drools.workbench.screens.scenariosimulation.client.events.InsertColumnEvent;
 import org.drools.workbench.screens.scenariosimulation.client.events.InsertRowEvent;
 import org.drools.workbench.screens.scenariosimulation.client.events.PrependColumnEvent;
 import org.drools.workbench.screens.scenariosimulation.client.events.PrependRowEvent;
 import org.drools.workbench.screens.scenariosimulation.client.events.RedoEvent;
-import org.drools.workbench.screens.scenariosimulation.client.events.ReloadRightPanelEvent;
+import org.drools.workbench.screens.scenariosimulation.client.events.ReloadTestToolsEvent;
 import org.drools.workbench.screens.scenariosimulation.client.events.RunSingleScenarioEvent;
 import org.drools.workbench.screens.scenariosimulation.client.events.ScenarioGridReloadEvent;
 import org.drools.workbench.screens.scenariosimulation.client.events.ScenarioNotificationEvent;
@@ -72,15 +78,17 @@ import org.drools.workbench.screens.scenariosimulation.client.handlers.AppendCol
 import org.drools.workbench.screens.scenariosimulation.client.handlers.AppendRowEventHandler;
 import org.drools.workbench.screens.scenariosimulation.client.handlers.DeleteColumnEventHandler;
 import org.drools.workbench.screens.scenariosimulation.client.handlers.DeleteRowEventHandler;
-import org.drools.workbench.screens.scenariosimulation.client.handlers.DisableRightPanelEventHandler;
+import org.drools.workbench.screens.scenariosimulation.client.handlers.DisableTestToolsEventHandler;
+import org.drools.workbench.screens.scenariosimulation.client.handlers.DuplicateInstanceEventHandler;
 import org.drools.workbench.screens.scenariosimulation.client.handlers.DuplicateRowEventHandler;
-import org.drools.workbench.screens.scenariosimulation.client.handlers.EnableRightPanelEventHandler;
+import org.drools.workbench.screens.scenariosimulation.client.handlers.EnableTestToolsEventHandler;
+import org.drools.workbench.screens.scenariosimulation.client.handlers.ImportEventHandler;
 import org.drools.workbench.screens.scenariosimulation.client.handlers.InsertColumnEventHandler;
 import org.drools.workbench.screens.scenariosimulation.client.handlers.InsertRowEventHandler;
 import org.drools.workbench.screens.scenariosimulation.client.handlers.PrependColumnEventHandler;
 import org.drools.workbench.screens.scenariosimulation.client.handlers.PrependRowEventHandler;
 import org.drools.workbench.screens.scenariosimulation.client.handlers.RedoEventHandler;
-import org.drools.workbench.screens.scenariosimulation.client.handlers.ReloadRightPanelEventHandler;
+import org.drools.workbench.screens.scenariosimulation.client.handlers.ReloadTestToolsEventHandler;
 import org.drools.workbench.screens.scenariosimulation.client.handlers.RunSingleScenarioEventHandler;
 import org.drools.workbench.screens.scenariosimulation.client.handlers.ScenarioGridReloadEventHandler;
 import org.drools.workbench.screens.scenariosimulation.client.handlers.ScenarioNotificationEventHandler;
@@ -92,6 +100,7 @@ import org.drools.workbench.screens.scenariosimulation.client.handlers.UndoEvent
 import org.drools.workbench.screens.scenariosimulation.client.handlers.UnsupportedDMNEventHandler;
 import org.drools.workbench.screens.scenariosimulation.client.popup.ConfirmPopupPresenter;
 import org.drools.workbench.screens.scenariosimulation.client.popup.DeletePopupPresenter;
+import org.drools.workbench.screens.scenariosimulation.client.popup.FileUploadPopupPresenter;
 import org.drools.workbench.screens.scenariosimulation.client.popup.PreserveDeletePopupPresenter;
 import org.drools.workbench.screens.scenariosimulation.client.resources.i18n.ScenarioSimulationEditorConstants;
 import org.drools.workbench.screens.scenariosimulation.client.widgets.ScenarioGridColumn;
@@ -99,6 +108,8 @@ import org.kie.workbench.common.command.client.CommandResult;
 import org.kie.workbench.common.command.client.CommandResultBuilder;
 import org.uberfire.workbench.events.NotificationEvent;
 
+import static org.drools.workbench.screens.scenariosimulation.service.ImportExportType.CSV;
+
 /**
  * This class is meant to be a centralized listener for events fired up by UI, responding to them issuing specific <code>Command</code>s.
  * <p>
@@ -109,15 +120,17 @@ public class ScenarioSimulationEventHandler implements AppendColumnEventHandler,
                                                        AppendRowEventHandler,
                                                        DeleteColumnEventHandler,
                                                        DeleteRowEventHandler,
-                                                       DisableRightPanelEventHandler,
+                                                       DisableTestToolsEventHandler,
+                                                       DuplicateInstanceEventHandler,
                                                        DuplicateRowEventHandler,
-                                                       EnableRightPanelEventHandler,
+                                                       EnableTestToolsEventHandler,
+                                                       ImportEventHandler,
                                                        InsertColumnEventHandler,
                                                        InsertRowEventHandler,
                                                        PrependColumnEventHandler,
                                                        PrependRowEventHandler,
                                                        RedoEventHandler,
-                                                       ReloadRightPanelEventHandler,
+                                                       ReloadTestToolsEventHandler,
                                                        RunSingleScenarioEventHandler,
                                                        ScenarioGridReloadEventHandler,
                                                        ScenarioNotificationEventHandler,
@@ -131,6 +144,7 @@ public class ScenarioSimulationEventHandler implements AppendColumnEventHandler,
     protected DeletePopupPresenter deletePopupPresenter;
     protected PreserveDeletePopupPresenter preserveDeletePopupPresenter;
     protected ConfirmPopupPresenter confirmPopupPresenter;
+    protected FileUploadPopupPresenter fileUploadPopupPresenter;
 
     protected EventBus eventBus;
 
@@ -138,16 +152,12 @@ public class ScenarioSimulationEventHandler implements AppendColumnEventHandler,
 
     protected Event<NotificationEvent> notificationEvent;
 
-    protected ScenarioSimulationContext context;
+    protected ScenarioSimulationEditorPresenter scenarioSimulationEditorPresenter;
 
     protected ScenarioCommandRegistry scenarioCommandRegistry;
 
     protected ScenarioCommandManager scenarioCommandManager;
 
-    public ScenarioSimulationEventHandler() {
-        // CDI
-    }
-
     public void setEventBus(EventBus eventBus) {
         this.eventBus = eventBus;
         registerHandlers();
@@ -165,12 +175,16 @@ public class ScenarioSimulationEventHandler implements AppendColumnEventHandler,
         this.confirmPopupPresenter = confirmPopupPresenter;
     }
 
+    public void setFileUploadPopupPresenter(FileUploadPopupPresenter fileUploadPopupPresenter) {
+        this.fileUploadPopupPresenter = fileUploadPopupPresenter;
+    }
+
     public void setNotificationEvent(Event<NotificationEvent> notificationEvent) {
         this.notificationEvent = notificationEvent;
     }
 
-    public void setContext(ScenarioSimulationContext context) {
-        this.context = context;
+    public void setScenarioSimulationPresenter(ScenarioSimulationEditorPresenter scenarioSimulationEditorPresenter) {
+        this.scenarioSimulationEditorPresenter = scenarioSimulationEditorPresenter;
     }
 
     public void setScenarioCommandRegistry(ScenarioCommandRegistry scenarioCommandRegistry) {
@@ -181,6 +195,10 @@ public class ScenarioSimulationEventHandler implements AppendColumnEventHandler,
         this.scenarioCommandManager = scenarioCommandManager;
     }
 
+    private ScenarioSimulationContext getFocusedContext() {
+        return scenarioSimulationEditorPresenter.getFocusedContext();
+    }
+
     @PreDestroy
     public void unregisterHandlers() {
         handlerRegistrationList.forEach(HandlerRegistration::removeHandler);
@@ -188,134 +206,208 @@ public class ScenarioSimulationEventHandler implements AppendColumnEventHandler,
 
     @Override
     public void onEvent(AppendColumnEvent event) {
+        ScenarioSimulationContext context = getFocusedContext();
         context.getStatus().setColumnId(String.valueOf(new Date().getTime()));
         context.getStatus().setColumnGroup(event.getColumnGroup());
-        commonExecution(context, new AppendColumnCommand());
+        commonExecution(context,
+                        new AppendColumnCommand(),
+                        true);
     }
 
     @Override
     public void onEvent(AppendRowEvent event) {
-        commonExecution(context, new AppendRowCommand());
+        commonExecution(getFocusedContext(),
+                        new AppendRowCommand(),
+                        true);
     }
 
     @Override
     public void onEvent(DeleteColumnEvent event) {
+        ScenarioSimulationContext context = getFocusedContext();
         context.getStatus().setColumnIndex(event.getColumnIndex());
         context.getStatus().setColumnGroup(event.getColumnGroup());
-        commonExecution(context, new DeleteColumnCommand());
+        context.getStatus().setDisable(true);
+        context.getStatus().setOpenDock(false);
+        context.getStatus().setAsProperty(event.isAsProperty());
+        commonExecution(context,
+                        new DeleteColumnCommand(),
+                        true);
     }
 
     @Override
     public void onEvent(DeleteRowEvent event) {
+        ScenarioSimulationContext context = getFocusedContext();
         context.getStatus().setRowIndex(event.getRowIndex());
-        commonExecution(context, new DeleteRowCommand());
+        commonExecution(context,
+                        new DeleteRowCommand(),
+                        true);
     }
 
     @Override
-    public void onEvent(DisableRightPanelEvent event) {
-        commonExecution(context, new DisableRightPanelCommand());
+    public void onEvent(DisableTestToolsEvent event) {
+        commonExecution(getFocusedContext(),
+                        new DisableTestToolsCommand(),
+                        false);
+    }
+
+    @Override
+    public void onEvent(DuplicateInstanceEvent event) {
+        ScenarioSimulationContext context = getFocusedContext();
+        context.getStatus().setColumnId(String.valueOf(new Date().getTime()));
+        context.getStatus().setColumnIndex(event.getColumnIndex());
+        context.getStatus().setRight(true);
+        context.getStatus().setAsProperty(false);
+        context.getStatus().setFullPackage(
+                ((ScenarioGridColumn) context.getModel().getSelectedColumn()).getFactIdentifier().getPackageWithoutClassName());
+        commonExecution(context,
+                        new DuplicateInstanceCommand(),
+                        true);
     }
 
     @Override
     public void onEvent(DuplicateRowEvent event) {
+        ScenarioSimulationContext context = getFocusedContext();
         context.getStatus().setRowIndex(event.getRowIndex());
-        commonExecution(context, new DuplicateRowCommand());
+        commonExecution(context,
+                        new DuplicateRowCommand(),
+                        true);
     }
 
     @Override
-    public void onEvent(EnableRightPanelEvent event) {
+    public void onEvent(EnableTestToolsEvent event) {
+        ScenarioSimulationContext context = getFocusedContext();
         context.getStatus().setFilterTerm(event.getFilterTerm());
-        context.getStatus().setPropertyName(event.getPropertyName());
+        context.getStatus().setPropertyNameElements(event.getPropertyNameElements());
         context.getStatus().setNotEqualsSearch(event.isNotEqualsSearch());
-        commonExecution(context, new EnableRightPanelCommand());
+        commonExecution(context,
+                        new EnableTestToolsCommand(),
+                        false);
+    }
+
+    @Override
+    public void onEvent(ImportEvent event) {
+        org.uberfire.mvp.Command okImportCommand = () -> {
+            ImportCommand importCommand = new ImportCommand();
+            importCommand.setFileContent(fileUploadPopupPresenter.getFileContents());
+            commonExecution(getFocusedContext(),
+                            importCommand,
+                            false);
+        };
+        fileUploadPopupPresenter.show(Collections.singletonList(CSV.getExtension()),
+                                      ScenarioSimulationEditorConstants.INSTANCE.selectImportFile(),
+                                      ScenarioSimulationEditorConstants.INSTANCE.importLabel(),
+                                      okImportCommand);
     }
 
     @Override
     public void onEvent(InsertColumnEvent event) {
+        ScenarioSimulationContext context = getFocusedContext();
         context.getStatus().setColumnId(String.valueOf(new Date().getTime()));
         context.getStatus().setColumnIndex(event.getColumnIndex());
         context.getStatus().setRight(event.isRight());
         context.getStatus().setAsProperty(event.isAsProperty());
-        commonExecution(context, new InsertColumnCommand());
+        commonExecution(context,
+                        new InsertColumnCommand(),
+                        true);
     }
 
     @Override
     public void onEvent(InsertRowEvent event) {
+        ScenarioSimulationContext context = getFocusedContext();
         context.getStatus().setRowIndex(event.getRowIndex());
-        commonExecution(context, new InsertRowCommand());
+        commonExecution(context,
+                        new InsertRowCommand(),
+                        true);
     }
 
     @Override
     public void onEvent(PrependColumnEvent event) {
+        ScenarioSimulationContext context = getFocusedContext();
         context.getStatus().setColumnId(String.valueOf(new Date().getTime()));
         context.getStatus().setColumnGroup(event.getColumnGroup());
-        commonExecution(context, new PrependColumnCommand());
+        commonExecution(context,
+                        new PrependColumnCommand(),
+                        true);
     }
 
     @Override
     public void onEvent(PrependRowEvent event) {
-        commonExecution(context, new PrependRowCommand());
+        commonExecution(getFocusedContext(),
+                        new PrependRowCommand(),
+                        true);
     }
 
     @Override
     public void onEvent(RedoEvent event) {
-        final CommandResult<ScenarioSimulationViolation> status = scenarioCommandRegistry.redo(context);
+        final CommandResult<ScenarioSimulationViolation> status = scenarioCommandRegistry.redo(getFocusedContext());
         if (Objects.equals(CommandResult.Type.ERROR, status.getType())) {
             commonNotifyError(status, ScenarioSimulationEditorConstants.INSTANCE.redo());
         }
     }
 
     @Override
-    public void onEvent(ReloadRightPanelEvent event) {
+    public void onEvent(ReloadTestToolsEvent event) {
+        ScenarioSimulationContext context = getFocusedContext();
         context.getStatus().setDisable(event.isDisable());
         context.getStatus().setOpenDock(event.isOpenDock());
-        commonExecution(context, new ReloadRightPanelCommand());
+        commonExecution(context,
+                        new ReloadTestToolsCommand(),
+                        false);
     }
 
     @Override
     public void onEvent(RunSingleScenarioEvent event) {
+        ScenarioSimulationContext context = getFocusedContext();
         context.getStatus().setRowIndex(event.getRowIndex());
-        commonExecution(context, new RunSingleScenarioCommand());
+        commonExecution(context,
+                        new RunSingleScenarioCommand(),
+                        false);
     }
 
     @Override
     public void handle(ScenarioGridReloadEvent event) {
-        context.getScenarioGridPanel().onResize();
+        getFocusedContext().getScenarioGridPanel().onResize();
     }
 
     @Override
     public void onEvent(ScenarioNotificationEvent event) {
-        notificationEvent.fire(new NotificationEvent(event.getMessage(), event.getType()));
+        notificationEvent.fire(new NotificationEvent(event.getMessage(), event.getNotificationType()));
     }
 
     @Override
     public void onEvent(SetGridCellValueEvent event) {
+        ScenarioSimulationContext context = getFocusedContext();
         context.getStatus().setRowIndex(event.getRowIndex());
         context.getStatus().setColumnIndex(event.getColumnIndex());
-        context.getStatus().setCellValue(event.getCellValue());
-        commonExecution(context, new SetGridCellValueCommand());
+        context.getStatus().setGridCellValue(event.getCellValue());
+        commonExecution(context,
+                        new SetGridCellValueCommand(),
+                        false);
     }
 
     @Override
     public void onEvent(SetHeaderCellValueEvent event) {
+        ScenarioSimulationContext context = getFocusedContext();
         context.getStatus().setRowIndex(event.getRowIndex());
         context.getStatus().setColumnIndex(event.getColumnIndex());
-        context.getStatus().setCellValue(event.getCellValue());
-        commonExecution(context, new SetHeaderCellValueCommand(event.isInstanceHeader(), event.isPropertyHeader()));
+        context.getStatus().setHeaderCellValue(event.getHeaderCellValue());
+        commonExecution(context,
+                        new SetHeaderCellValueCommand(event.isInstanceHeader(), event.isPropertyHeader()),
+                        false);
     }
 
     @Override
     public void onEvent(SetInstanceHeaderEvent event) {
-        if (context.getModel().getSelectedColumn() == null) {
-            return;
-        }
-        if (context.getModel().isSameSelectedColumnType(event.getClassName())) {
+        ScenarioSimulationContext context = getFocusedContext();
+        if (context.getModel().isSameInstanceType(event.getClassName())) {
             return;
         }
         context.getStatus().setFullPackage(event.getFullPackage());
         context.getStatus().setClassName(event.getClassName());
         if (((ScenarioGridColumn) context.getModel().getSelectedColumn()).isInstanceAssigned()) {
-            org.uberfire.mvp.Command okPreserveCommand = () -> commonExecution(context, new SetInstanceHeaderCommand());
+            org.uberfire.mvp.Command okPreserveCommand = () -> commonExecution(context,
+                                                                               new SetInstanceHeaderCommand(),
+                                                                               true);
             deletePopupPresenter.show(ScenarioSimulationEditorConstants.INSTANCE.changeTypeMainTitle(),
                                       ScenarioSimulationEditorConstants.INSTANCE.changeTypeMainQuestion(),
                                       ScenarioSimulationEditorConstants.INSTANCE.changeTypeText1(),
@@ -324,35 +416,44 @@ public class ScenarioSimulationEventHandler implements AppendColumnEventHandler,
                                       ScenarioSimulationEditorConstants.INSTANCE.changeType(),
                                       okPreserveCommand);
         } else {
-            commonExecution(context, new SetInstanceHeaderCommand());
+            commonExecution(context,
+                            new SetInstanceHeaderCommand(),
+                            true);
         }
-        context.getScenarioGridPanel().setFocus(true);
     }
 
     @Override
     public void onEvent(SetPropertyHeaderEvent event) {
+        ScenarioSimulationContext context = getFocusedContext();
         if (context.getModel().getSelectedColumn() == null) {
             return;
         }
-        if (context.getModel().isAlreadyAssignedProperty(event.getValue())) {
-            onEvent(new ScenarioNotificationEvent("Property \"" + event.getValue() + "\" already assigned", NotificationEvent.NotificationType.ERROR));
+        if (context.getModel().isAlreadyAssignedProperty(event.getPropertyNameElements())) {
+            String value = String.join(".", event.getPropertyNameElements());
+            onEvent(new ScenarioNotificationEvent("Property \"" + value + "\" already assigned", NotificationEvent.NotificationType.ERROR));
             return;
         }
         context.getStatus().setFullPackage(event.getFullPackage());
-        context.getStatus().setValue(event.getValue());
+        context.getStatus().setPropertyNameElements(event.getPropertyNameElements());
         context.getStatus().setValueClassName(event.getValueClassName());
         if (context.getModel().isSelectedColumnEmpty()) {
-            commonExecution(context, new SetPropertyHeaderCommand());
-        } else if (context.getModel().isSameSelectedColumnProperty(event.getValue())) {
+            commonExecution(context,
+                            new SetPropertyHeaderCommand(),
+                            true);
+        } else if (context.getModel().isSameSelectedColumnProperty(event.getPropertyNameElements())) {
             return;
         } else if (context.getModel().isSameSelectedColumnType(event.getValueClassName())) {
             org.uberfire.mvp.Command okDeleteCommand = () -> {
                 context.getStatus().setKeepData(false);
-                commonExecution(context, new SetPropertyHeaderCommand());
+                commonExecution(context,
+                                new SetPropertyHeaderCommand(),
+                                true);
             };
             org.uberfire.mvp.Command okPreserveCommand = () -> {
                 context.getStatus().setKeepData(true);
-                commonExecution(context, new SetPropertyHeaderCommand());
+                commonExecution(context,
+                                new SetPropertyHeaderCommand(),
+                                true);
             };
             preserveDeletePopupPresenter.show(ScenarioSimulationEditorConstants.INSTANCE.preserveDeleteScenarioMainTitle(),
                                               ScenarioSimulationEditorConstants.INSTANCE.preserveDeleteScenarioMainQuestion(),
@@ -367,7 +468,9 @@ public class ScenarioSimulationEventHandler implements AppendColumnEventHandler,
         } else if (!context.getModel().isSameSelectedColumnType(event.getValueClassName())) {
             org.uberfire.mvp.Command okPreserveCommand = () -> {
                 context.getStatus().setKeepData(false);
-                commonExecution(context, new SetPropertyHeaderCommand());
+                commonExecution(context,
+                                new SetPropertyHeaderCommand(),
+                                true);
             };
             deletePopupPresenter.show(ScenarioSimulationEditorConstants.INSTANCE.deleteScenarioMainTitle(),
                                       ScenarioSimulationEditorConstants.INSTANCE.deleteScenarioMainQuestion(),
@@ -377,13 +480,11 @@ public class ScenarioSimulationEventHandler implements AppendColumnEventHandler,
                                       ScenarioSimulationEditorConstants.INSTANCE.deleteValues(),
                                       okPreserveCommand);
         }
-
-        context.getScenarioGridPanel().setFocus(true);
     }
 
     @Override
     public void onEvent(UndoEvent event) {
-        final CommandResult<ScenarioSimulationViolation> status = scenarioCommandRegistry.undo(context);
+        final CommandResult<ScenarioSimulationViolation> status = scenarioCommandRegistry.undo(getFocusedContext());
         if (Objects.equals(CommandResult.Type.ERROR, status.getType())) {
             commonNotifyError(status, ScenarioSimulationEditorConstants.INSTANCE.undo());
         }
@@ -401,7 +502,9 @@ public class ScenarioSimulationEventHandler implements AppendColumnEventHandler,
      * @param context
      * @param command
      */
-    protected void commonExecution(ScenarioSimulationContext context, AbstractScenarioSimulationCommand command) {
+    protected void commonExecution(final ScenarioSimulationContext context,
+                                   final AbstractScenarioSimulationCommand command,
+                                   final boolean focusGridAfterExecution) {
         final CommandResult<ScenarioSimulationViolation> status = scenarioCommandManager.execute(context, command);
         if (Objects.equals(CommandResult.Type.ERROR, status.getType())) {
             String operation = new StringBuilder()
@@ -412,12 +515,15 @@ public class ScenarioSimulationEventHandler implements AppendColumnEventHandler,
             commonNotifyError(status, operation);
         } else if (Objects.equals(CommandResultBuilder.SUCCESS, status) && command.isUndoable()) {
             scenarioCommandRegistry.register(context, command);
+            if (focusGridAfterExecution) {
+                context.getScenarioGridPanel().setFocus(true);
+            }
         }
     }
 
     protected void commonNotifyError(CommandResult<ScenarioSimulationViolation> status, String operation) {
         String violations = StreamSupport.stream(status.getViolations().spliterator(), false)
-                .map(violation -> violation.getMessage())
+                .map(ScenarioSimulationViolation::getMessage)
                 .collect(Collectors.joining("\r\n"));
         String message = new StringBuilder()
                 .append(operation + ": " + status.getType())
@@ -432,15 +538,17 @@ public class ScenarioSimulationEventHandler implements AppendColumnEventHandler,
         handlerRegistrationList.add(eventBus.addHandler(AppendRowEvent.TYPE, this));
         handlerRegistrationList.add(eventBus.addHandler(DeleteColumnEvent.TYPE, this));
         handlerRegistrationList.add(eventBus.addHandler(DeleteRowEvent.TYPE, this));
-        handlerRegistrationList.add(eventBus.addHandler(DisableRightPanelEvent.TYPE, this));
+        handlerRegistrationList.add(eventBus.addHandler(DisableTestToolsEvent.TYPE, this));
+        handlerRegistrationList.add(eventBus.addHandler(DuplicateInstanceEvent.TYPE, this));
         handlerRegistrationList.add(eventBus.addHandler(DuplicateRowEvent.TYPE, this));
-        handlerRegistrationList.add(eventBus.addHandler(EnableRightPanelEvent.TYPE, this));
+        handlerRegistrationList.add(eventBus.addHandler(EnableTestToolsEvent.TYPE, this));
+        handlerRegistrationList.add(eventBus.addHandler(ImportEvent.TYPE, this));
         handlerRegistrationList.add(eventBus.addHandler(InsertColumnEvent.TYPE, this));
         handlerRegistrationList.add(eventBus.addHandler(InsertRowEvent.TYPE, this));
         handlerRegistrationList.add(eventBus.addHandler(PrependColumnEvent.TYPE, this));
         handlerRegistrationList.add(eventBus.addHandler(PrependRowEvent.TYPE, this));
         handlerRegistrationList.add(eventBus.addHandler(RedoEvent.TYPE, this));
-        handlerRegistrationList.add(eventBus.addHandler(ReloadRightPanelEvent.TYPE, this));
+        handlerRegistrationList.add(eventBus.addHandler(ReloadTestToolsEvent.TYPE, this));
         handlerRegistrationList.add(eventBus.addHandler(RunSingleScenarioEvent.TYPE, this));
         handlerRegistrationList.add(eventBus.addHandler(ScenarioGridReloadEvent.TYPE, this));
         handlerRegistrationList.add(eventBus.addHandler(ScenarioNotificationEvent.TYPE, this));
